package com.thomasbet.endpoints.DTO;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.core.JsonParser;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.JsonDeserializer;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.datatype.jsr310.deser.LocalDateDeserializer;
import com.fasterxml.jackson.datatype.jsr310.ser.LocalDateSerializer;
import jakarta.persistence.Column;
import jakarta.persistence.Id;

import java.io.IOException;
import java.time.Instant;

public class EventDTO {

    @JsonProperty("id")
    private String eventId;

    @JsonProperty("sport_key")
    private String sportKey;

    @JsonProperty("sport_title")
    private String sportTitle;

    @JsonProperty("commence_time")
    @JsonDeserialize(using = UnixTimestampDeserializer.class)
    private Long commenceTime;

    @JsonProperty("home_team")
    private String homeTeam;

    @JsonProperty("away_team")
    private String awayTeam;

    @JsonProperty("sport_type")
    private String sportType;

    @JsonProperty("home_team_score")
    private Integer homeTeamScore;

    @JsonProperty("away_team_score")
    private Integer awayTeamScore;

    public EventDTO() {
    }

    public EventDTO(String eventId, String sportKey, String sportTitle, Long commenceTime, String homeTeam, String awayTeam, String sportType, Integer homeTeamScore, Integer awayTeamScore) {
        this.eventId = eventId;
        this.sportKey = sportKey;
        this.sportTitle = sportTitle;
        this.commenceTime = commenceTime;
        this.homeTeam = homeTeam;
        this.awayTeam = awayTeam;
        this.sportType = sportType;
        this.homeTeamScore = homeTeamScore;
        this.awayTeamScore = awayTeamScore;
    }

    public EventDTO(String sportKey, String sportTitle, Long commenceTime, String homeTeam, String awayTeam, String sportType, Integer homeTeamScore, Integer awayTeamScore) {
        this.sportKey = sportKey;
        this.sportTitle = sportTitle;
        this.commenceTime = commenceTime;
        this.homeTeam = homeTeam;
        this.awayTeam = awayTeam;
        this.sportType = sportType;
        this.homeTeamScore = homeTeamScore;
        this.awayTeamScore = awayTeamScore;
    }

    public String getEventId() {
        return eventId;
    }

    public void setEventId(String eventId) {
        this.eventId = eventId;
    }

    public String getSportKey() {
        return sportKey;
    }

    public void setSportKey(String sportKey) {
        this.sportKey = sportKey;
    }

    public String getSportTitle() {
        return sportTitle;
    }

    public void setSportTitle(String sportTitle) {
        this.sportTitle = sportTitle;
    }

    public Long getCommenceTime() {
        return commenceTime;
    }

    public void setCommenceTime(Long commenceTime) {
        this.commenceTime = commenceTime;
    }

    public String getHomeTeam() {
        return homeTeam;
    }

    public void setHomeTeam(String homeTeam) {
        this.homeTeam = homeTeam;
    }

    public String getAwayTeam() {
        return awayTeam;
    }

    public void setAwayTeam(String awayTeam) {
        this.awayTeam = awayTeam;
    }

    public String getSportType() {
        return sportType;
    }

    public void setSportType(String sportType) {
        this.sportType = sportType;
    }

    public Integer getHomeTeamScore() {
        return homeTeamScore;
    }

    public void setHomeTeamScore(Integer homeTeamScore) {
        this.homeTeamScore = homeTeamScore;
    }

    public Integer getAwayTeamScore() {
        return awayTeamScore;
    }

    public void setAwayTeamScore(Integer awayTeamScore) {
        this.awayTeamScore = awayTeamScore;
    }

    @Override
    public String toString() {
        return "EventDTO{" +
                "eventId='" + eventId + '\'' +
                ", sportKey='" + sportKey + '\'' +
                ", sportTitle='" + sportTitle + '\'' +
                ", commenceTime=" + commenceTime +
                ", homeTeam='" + homeTeam + '\'' +
                ", awayTeam='" + awayTeam + '\'' +
                ", sportType='" + sportType + '\'' +
                ", homeTeamScore=" + homeTeamScore +
                ", awayTeamScore=" + awayTeamScore +
                '}';
    }

    public static class UnixTimestampDeserializer extends JsonDeserializer<Long> {

        @Override
        public Long deserialize(JsonParser jsonParser, DeserializationContext deserializationContext) throws IOException {
            String dateString = jsonParser.getText();
            Instant instant = Instant.parse(dateString); // Parse the string into an Instant
            return instant.toEpochMilli(); // Convert the Instant to milliseconds since epoch
        }
    }
}
