package com.thomasbet.endpoints.controller;

import com.thomasbet.endpoints.DTO.BlogDTO;
import com.thomasbet.endpoints.DTO.PageableResponse;
import com.thomasbet.endpoints.DTO.StrategyDTO;
import com.thomasbet.endpoints.Model.Blog;
import com.thomasbet.endpoints.Model.Strategy;
import com.thomasbet.endpoints.service.BlogService;
import com.thomasbet.endpoints.service.StrategyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/api/blogs")
public class BlogRestAPI {

    @Autowired
    private BlogService blogService;

    public BlogRestAPI(BlogService blogService) {
        this.blogService = blogService;
    }

    //stránkované články které napsat přihlášený uživatel
    @GetMapping
    public PageableResponse<Page<BlogDTO>> getBlogs(@RequestParam(required = false) Long userId,
                                                         @RequestParam(required = false) int offset,
                                                         @RequestParam(required = false) int page){
        Page<BlogDTO> blogsList = blogService.getBlogsByUserIdPaged(userId, offset, page);


        return new PageableResponse<>(offset, page, blogsList);
    }

    //stránkované články
    @GetMapping("/{offset}/{page}")
    public PageableResponse<Page<BlogDTO>> getPageableBlogs(@PathVariable int offset, @PathVariable int page){
        Page<BlogDTO> blogs = blogService.getBlogWithPagination(offset, page);
        return new PageableResponse<>(offset, page, blogs);
    }

    @GetMapping(path = "/{id}")
    public ResponseEntity<BlogDTO> getBlogById(@PathVariable Long id){
        BlogDTO blog = blogService.getBlogById(id);

        if(blog != null){
            return ResponseEntity.ok(blog);
        }else{
            return ResponseEntity.notFound().build();
        }
    }

    //vytvoření blogu v DB
    @PostMapping
    public ResponseEntity<Blog> createBlog(@RequestBody BlogDTO blog){
        try{
            Blog newBlog = blogService.createBlog(blog);
            if(newBlog != null){
                return ResponseEntity.ok(newBlog);
            }else{
                return ResponseEntity.notFound().build();
            }
        }catch(Exception E){
            return ResponseEntity.notFound().build();
        }
    }

    //počet stránek při vypisování vlastních článků
    @GetMapping("/count")
    public int getBlogsCount(@RequestParam(required = true) int offset,
                                  @RequestParam(required = true) boolean myArticles,
                                  @RequestParam(required = true) Long userId){
        return blogService.getBlogCount(offset, myArticles, userId);
    }


    //smazání článku
    @DeleteMapping("/{id}")
    public void deleteBlog(@PathVariable Long id){
        blogService.deleteBlog(id);
    }


    //úprava článku
    @PatchMapping
    public void updateBlog(@RequestBody BlogDTO blogDTO){
        blogService.updateBlog(blogDTO);
    }
}
