package com.thomasbet.endpoints.controller;

import com.thomasbet.endpoints.DTO.EventDTO;
import com.thomasbet.endpoints.DTO.PageableResponse;
import com.thomasbet.endpoints.DTO.StrategyDTO;
import com.thomasbet.endpoints.service.EventService;
import org.apache.coyote.Response;
import org.springframework.data.domain.Page;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/api/events")
public class EventRestAPI {


    private EventService eventService;

    public EventRestAPI(EventService eventService) {
        this.eventService = eventService;
    }

    //vrácení hodnot budoucích zápasů (rozvrhu zápasů)
    @GetMapping("/{offset}/{page}/{sportType}/{state}")
    public PageableResponse<Page<EventDTO>> getAllUpcomingEvents(@PathVariable int offset, @PathVariable int page, @PathVariable String sportType, @PathVariable String state){
        boolean upcoming = state.equals("upcoming");
        Page<EventDTO> events = eventService.getEventsWithPagination(offset, page, sportType, upcoming);
        return new PageableResponse<>(offset, page, events);
    }

    //počet zápasů, stránkování podle druhu sportu plus vrácení jen nadcházejících
    @GetMapping("/count")
    public int getEventsCount(@RequestParam(required = true) int offset,
                              @RequestParam(required = true) String sportType,
                              @RequestParam(required = true) String state){
        boolean upcoming = state.equals("upcoming");
        return eventService.getEventCount(offset, sportType, upcoming);
    }

    //identifikace eventu podle ID
    @GetMapping("/{id}")
    public EventDTO getEventById(@PathVariable String id){
        return eventService.findById(id);
    }
}
