package com.thomasbet.endpoints.controller;

import com.thomasbet.endpoints.DTO.EventDTO;
import com.thomasbet.endpoints.rest_clients.OddsRestClient;
import com.thomasbet.endpoints.service.EventService;
import com.thomasbet.endpoints.service.ScoreService;
import com.thomasbet.endpoints.service.SportService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.net.MalformedURLException;
import java.util.List;

@RestController
@RequestMapping("/api/fetch")
public class FetchDataAPI {

    @Autowired
    private EventService eventService;

    @Autowired
    private SportService sportService;

    @Autowired
    private ScoreService scoreService;

    @Autowired
    private OddsRestClient oddsRestClient;


    public FetchDataAPI(EventService eventService, SportService sportService, ScoreService scoreService, OddsRestClient oddsRestClient) {
        this.eventService = eventService;
        this.sportService = sportService;
        this.scoreService = scoreService;
        this.oddsRestClient = oddsRestClient;
    }

    //fetchování eventů podle sportu
    @GetMapping("/events/{sportKey}")
    public void fetchEventsFromOddsBySportKey(@PathVariable String sportKey){
        oddsRestClient.getEventsBySportKey(sportKey)
                .subscribe(eventDTO -> {
                    eventDTO.setSportType(sportService.getSportById(eventDTO.getSportKey()).getSport());
                    eventService.saveEvent(eventDTO);
                });
    }

    //fetchování vfšech eventů, smazání předchozích hodnot
    @GetMapping("/events/all")
    public void fetchAllEvents(){
        removeEventData();
        sportService.getAllSports().forEach(sport -> {
            fetchEventsFromOddsBySportKey(sport.getSportId());
        });
    }

    //smazání předchozích hodnot ručně
    @GetMapping("/events/remove/all")
    public void removeEventData(){
        eventService.removeAllData();
    }


    //fetchování skóre k odehraným zápasům podle sportu
    @GetMapping("/scores/{sportKey}")
    public void fetchScoresFromOddsBySportKey(@PathVariable String sportKey) throws MalformedURLException {
        oddsRestClient.getScoresBySportKey(sportKey).forEach(score -> scoreService.saveScore(score));
    }

    //fetchování všech skóre
    @GetMapping("/scores/all")
    public void fetchAllScores(){
        removeScoresData();
        sportService.getAllSports().forEach(sport -> {
            try {
                fetchScoresFromOddsBySportKey(sport.getSportId());
            } catch (MalformedURLException e) {
                throw new RuntimeException(e);
            }
        });
    }

    //smazání hodnot skóre
    @GetMapping("/scores/remove/all")
    public void removeScoresData(){
        scoreService.removeAllData();
    }

}
