package com.thomasbet.endpoints.controller;

import com.thomasbet.endpoints.DTO.PageableResponse;
import com.thomasbet.endpoints.DTO.StrategyDTO;
import com.thomasbet.endpoints.Model.Strategy;
import com.thomasbet.endpoints.service.StrategyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.List;

@RestController
@RequestMapping(path = "/api/strategies")
public class StrategyRestAPI {

    @Autowired
    private StrategyService strategyService;

    public StrategyRestAPI(StrategyService strategyService) {
        this.strategyService = strategyService;
    }


    //vrácení všech strategií podle uživatele (volitelně) plus stránkování
    @GetMapping
    public PageableResponse<Page<StrategyDTO>> getStrategies(@RequestParam(required = false) Long userId,
                                                             @RequestParam(required = false) int offset,
                                                             @RequestParam(required = false) int page){
        Page<StrategyDTO> strategiesList = strategyService.getStrategiesByUserIdPaged(userId, offset, page);


        return new PageableResponse<>(offset, page, strategiesList);
    }

    //stránkování strategií
    @GetMapping("/{offset}/{page}")
    public PageableResponse<Page<StrategyDTO>> getPageableStrategies(@PathVariable int offset, @PathVariable int page){
        Page<StrategyDTO> strategies = strategyService.getStrategyWithPagination(offset, page);
        return new PageableResponse<>(offset, page, strategies);
    }

    //vrácení ID strategie
    @GetMapping(path = "/{id}")
    public ResponseEntity<StrategyDTO> getStrategyById(@PathVariable Long id){
        StrategyDTO strategy = strategyService.getStrategyById(id);

        if(strategy != null){
            return ResponseEntity.ok(strategy);
        }else{
            return ResponseEntity.notFound().build();
        }
    }

    //vytvoření strategie
    @PostMapping
    public ResponseEntity<Strategy> createStrategy(@RequestBody StrategyDTO strategy){
        try{
            Strategy newStrategy = strategyService.createStrategy(strategy);
            if(newStrategy != null){
                return ResponseEntity.ok(newStrategy);
            }else{
                return ResponseEntity.notFound().build();
            }
        }catch(Exception E){
            return ResponseEntity.notFound().build();
        }
    }

    //zjištění počtu strategií pro stránkování, zjištění zdali se jedná o všechny strategie nebo jen strategie uživatele
    @GetMapping("/count")
    public int getStrategiesCount(@RequestParam(required = true) int offset,
                                  @RequestParam(required = true) boolean myStrategies,
                                  @RequestParam(required = true) Long userId){
        return strategyService.getStrategiesCount(offset, myStrategies, userId);
    }


    //smazání strategie
    @DeleteMapping("/{id}")
    public void deleteStrategy(@PathVariable Long id){
        strategyService.deleteStrategy(id);
    }


    //úprava strategie
    @PatchMapping
    public void updateStrategy(@RequestBody StrategyDTO strategyDTO){
        strategyService.updateStrategy(strategyDTO);
    }

    /*
    @GetMapping
    public ResponseEntity<List<StrategyDTO>> getStrategiesByUserId(@RequestParam(required = true, name = "userId") Long id){
        List<StrategyDTO> strategiesList = strategyService.getStrategiesByUserId(id);

        if(!strategiesList.isEmpty()){
            return ResponseEntity.ok(strategiesList);
        }else{
            return ResponseEntity.notFound().build();
        }
    }

     */

}
