package com.thomasbet.endpoints.mappers;

import com.thomasbet.endpoints.DTO.BetDTO;
import com.thomasbet.endpoints.Model.Bet;
import com.thomasbet.endpoints.Model.Event;
import com.thomasbet.endpoints.Model.User;
import com.thomasbet.endpoints.service.EventService;
import com.thomasbet.endpoints.service.UserService;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.Named;

@Mapper
public interface BetMapper {

    @Mapping(source = "user", target = "userId", qualifiedByName = "userToUserId")
    @Mapping(source = "event", target = "eventId", qualifiedByName = "eventToEventId")
    BetDTO mapBetToBetDTO(Bet bet);


    default Bet mapBetDTOToBet(BetDTO betDTO, UserService userService, EventService eventService, EventMapper eventMapper){
        Bet entity = new Bet();
        entity.setBetType(betDTO.getBetType());
        entity.setId(betDTO.getId());
        entity.setValue(betDTO.getValue());
        entity.setOdd(betDTO.getOdd());
        entity.setEvent(eventMapper.eventDTOToEvent(eventService.findById(betDTO.getEventId())));
        entity.setUser(userService.getUserById((long) betDTO.getUserId()));


        return entity;
    }


    @Named("userToUserId")
    public static Long userToUserId(User user) {
        return user.getId();
    }

    @Named("eventToEventId")
    public static String eventToEventId(Event event) {
        return event.getEventId();
    }

}
