package com.thomasbet.endpoints.rest_clients;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.google.gson.JsonObject;
import com.thomasbet.endpoints.DTO.EventDTO;
import com.thomasbet.endpoints.Model.Score;
import org.json.JSONArray;
import org.json.JSONObject;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Component;
import org.springframework.stereotype.Service;
import org.springframework.web.reactive.function.client.WebClient;
import reactor.core.publisher.Flux;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;

@Component
public class OddsRestClient {

    @Value("${odds.api.key}")
    private String API_KEY;

    //napojení na ODDs api pro funkčnosti
    public Flux<EventDTO> getEventsBySportKey(String sportKey){
        WebClient webClient = WebClient.create("https://api.the-odds-api.com/v4/sports/");
        Flux<EventDTO> eventsFlux = webClient.get()
                .uri(sportKey + "/events?apiKey=" + API_KEY)
                .accept(MediaType.APPLICATION_JSON)
                .retrieve()
                .bodyToFlux(EventDTO.class);
        return eventsFlux;
    }


    //parsování vrácených JSON polí pro získání skóre, které je až 4. pole
    public List<Score> getScoresBySportKey(String sportKey) throws MalformedURLException {
        String url = "https://api.the-odds-api.com/v4/sports/";
        url = url.concat(sportKey + "/scores?daysFrom=2&apiKey=" + API_KEY);
        URL apiUrl = new URL(url);

        StringBuilder jsonResponse = new StringBuilder();

        try{
            HttpURLConnection urlConnection = (HttpURLConnection) apiUrl.openConnection();
            urlConnection.setRequestMethod("GET");
            urlConnection.setRequestProperty("Accept", "application/json");
            //urlConnection.connect();
            BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(urlConnection.getInputStream()));

            String line;
            while ((line = bufferedReader.readLine()) != null) {
                jsonResponse.append(line);
            }
            urlConnection.disconnect();


            System.out.println("JSON: " + jsonResponse.toString());
            JSONArray jsonObjects = new JSONArray(jsonResponse.toString());


            List<Score> scores = new ArrayList<>();

            for (int i=0; i<jsonObjects.length(); i++) {
                Score scoreToPush = new Score();
                JSONObject scoreObject = jsonObjects.getJSONObject(i);
                scoreToPush.setId(scoreObject.get("id").toString());
                if(!scoreObject.get("scores").toString().equals("null")) {
                    JSONArray scoresArray = new JSONArray(scoreObject.get("scores").toString());
                    for (int idx = 0; idx < scoresArray.length(); idx++) {
                        if(idx == 0){
                            scoreToPush.setHomeTeamScore(Integer.valueOf(scoresArray.getJSONObject(idx).get("score").toString()));
                        }else{
                            scoreToPush.setAwayTeamScore(Integer.valueOf(scoresArray.getJSONObject(idx).get("score").toString()));
                        }
                    }
                }
                scores.add(scoreToPush);
            }
            return scores;
        } catch (Exception e){
            e.printStackTrace();
            return null;
        }
    }


}
