package com.thomasbet.endpoints.service;

import com.thomasbet.endpoints.DTO.BetDTO;
import com.thomasbet.endpoints.Model.Bet;
import com.thomasbet.endpoints.mappers.BetMapper;
import com.thomasbet.endpoints.mappers.EventMapper;
import com.thomasbet.endpoints.repository.BetRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class BetService {

    @Autowired
    private BetRepository betRepository;

    @Autowired
    private BetMapper betMapper;

    @Autowired
    private UserService userService;

    @Autowired
    private EventService eventService;

    @Autowired
    private EventMapper eventMapper;

    public BetService(BetRepository betRepository, BetMapper betMapper, UserService userService, EventService eventService, EventMapper eventMapper) {
        this.betRepository = betRepository;
        this.betMapper = betMapper;
        this.userService = userService;
        this.eventService = eventService;
        this.eventMapper = eventMapper;
    }

    //servis pro vytvoření a manipulace se sázkou
    public BetDTO createBet(BetDTO betDTO){
        return betMapper.mapBetToBetDTO(betRepository.save(betMapper.mapBetDTOToBet(betDTO, userService, eventService, eventMapper)));
    }

    public Page<BetDTO> getBetsByUserId(Long userId, int page, int offset){
        return betRepository.findByUserId(userId, PageRequest.of(page, offset)).map(bet -> betMapper.mapBetToBetDTO(bet));
    }

    public int getMyBetsPageCount(int offset, Long userId){
        List<BetDTO> myBets = betRepository.findAll().stream()
                .filter(bet -> bet.getUser().getId().equals(userId))
                .map(bet -> betMapper.mapBetToBetDTO(bet))
                .toList();

        return (int) Math.ceil((double) myBets.size()/offset);
    }
}
