package com.thomasbet.endpoints.service;

import com.thomasbet.endpoints.DTO.BlogDTO;
import com.thomasbet.endpoints.DTO.StrategyDTO;
import com.thomasbet.endpoints.Model.Blog;
import com.thomasbet.endpoints.Model.Strategy;
import com.thomasbet.endpoints.mappers.BlogMapper;
import com.thomasbet.endpoints.repository.BlogRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

@Service
public class BlogService {

    @Autowired
    private BlogRepository blogRepository;

    @Autowired
    private BlogMapper blogMapper;

    @Autowired
    private UserService userService;

    //servis pro blog a články
    public BlogService(BlogRepository blogRepository, BlogMapper blogMapper, UserService userService) {
        this.blogRepository = blogRepository;
        this.blogMapper = blogMapper;
        this.userService = userService;
    }

    public List<Blog> getAllBlogs(){
        return blogRepository.findAll();
    }

    public BlogDTO getBlogById(Long id){
        if(blogRepository.findById(id).isPresent()){
            return blogMapper.blogToBlogDTO(blogRepository.findById(id).get());
        }else{
            return null;
        }
    }

    public Blog createBlog(BlogDTO blog){
        return blogRepository.save(blogMapper.blogDTOToBlog(blog, userService));
    }

    public Page<BlogDTO> getBlogWithPagination(int offset, int page){
        return blogRepository.findAll(PageRequest.of(page, offset)).map(entity -> blogMapper.blogToBlogDTO(entity));
    }

    public int getBlogCount(int offset, boolean myArticles, Long userId){
        List<Blog> articles = new ArrayList<>();
        if(!myArticles){
            articles = blogRepository.findAll();
            return (int) Math.ceil((double) articles.size()/offset);
        }else{
            articles = getBlogsByUserId(userId);
            return (int) Math.ceil((double) articles.size()/offset);
        }

    }

    public void deleteBlog(Long blogId){
        blogRepository.deleteById(blogId);
    }

    public void updateBlog(BlogDTO blog){
        blogRepository.save(blogMapper.blogDTOToBlog(blog, userService));
    }

    public Page<BlogDTO> getBlogsByUserIdPaged(Long id, int offset, int page){

        return blogRepository.getBlogsByUserId(id, PageRequest.of(page, offset))
                .map(blog -> blogMapper.blogToBlogDTO(blog));
    }

    public List<Blog> getBlogsByUserId(Long id){
        List <Blog> blogs = blogRepository.findAll().stream().filter(blog -> Objects.equals(blog.getUser().getId(), id)).toList();
        return blogs;
    }
}
