package com.thomasbet.endpoints.service;

import com.thomasbet.endpoints.DTO.StrategyDTO;
import com.thomasbet.endpoints.Model.Strategy;
import com.thomasbet.endpoints.mappers.StrategyMapper;
import com.thomasbet.endpoints.mappers.StrategyMapperImpl;
import com.thomasbet.endpoints.repository.StrategyRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.stereotype.Service;

import java.awt.print.Pageable;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.Optional;

@Service
public class StrategyService {

    @Autowired
    private StrategyRepository strategyRepository;

    @Autowired
    private StrategyMapper strategyMapper;

    @Autowired
    private UserService userService;

    //servis pro strategie
    public StrategyService(StrategyRepository strategyRepository, StrategyMapper strategyMapper, UserService userService) {
        this.strategyRepository = strategyRepository;
        this.strategyMapper = strategyMapper;
        this.userService = userService;
    }

    public List<StrategyDTO> getAllStrategies(){
        return strategyRepository.findAll().stream()
                .map(strategy -> strategyMapper.strategyToStrategyDTO(strategy))
                .toList();
    }

    public StrategyDTO getStrategyById(Long id){
        if(strategyRepository.findById(id).isPresent()){
            return strategyMapper.strategyToStrategyDTO(strategyRepository.findById(id).get());
        }else{
            return null;
        }
    }

    public Strategy createStrategy(StrategyDTO strategy){
        return strategyRepository.save(strategyMapper.strategyDTOtoStrategy(strategy, userService));
    }

    public Page<StrategyDTO> getStrategyWithPagination(int offset, int page){
        return strategyRepository.findAll(PageRequest.of(page, offset)).map(entity -> strategyMapper.strategyToStrategyDTO(entity));
    }

    public int getStrategiesCount(int offset, boolean myStrategies, Long userId){
        List<Strategy> strategies = new ArrayList<>();
        if(!myStrategies){
            strategies = strategyRepository.findAll();
            return (int) Math.ceil((double)strategies.size()/offset);
        }else{
            strategies = getStrategiesByUserId(userId);
            return (int) Math.ceil((double) strategies.size()/offset);
        }

    }

    public void deleteStrategy(Long strategyId){
        strategyRepository.deleteById(strategyId);
    }

    public void updateStrategy(StrategyDTO strategy){
        strategyRepository.save(strategyMapper.strategyDTOtoStrategy(strategy, userService));
    }

    public Page<StrategyDTO> getStrategiesByUserIdPaged(Long id, int offset, int page){

        return strategyRepository.getStrateigesByUserId(id, PageRequest.of(page, offset))
                .map(strategy -> strategyMapper.strategyToStrategyDTO(strategy));
    }

    public List<Strategy> getStrategiesByUserId(Long id){
        List <Strategy> strategies = strategyRepository.findAll().stream().filter(strategy -> Objects.equals(strategy.getUser().getId(), id)).toList();
        return strategies;
    }
}
