package com.thomasbet.endpoints.service;

import com.thomasbet.endpoints.DTO.UserDTO;
import com.thomasbet.endpoints.Model.User;
import com.thomasbet.endpoints.mappers.UserMapper;
import com.thomasbet.endpoints.repository.UserRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Optional;

@Service
public class UserService {

    @Autowired
    private final UserMapper userMapper;

    @Autowired
    private final UserRepository userRepository;

    //servis pro získávání uživatelů
    public UserService(UserMapper userMapper, UserRepository userRepository) {
        this.userMapper = userMapper;
        this.userRepository = userRepository;
    }

    public List<User> getAllUsers(){
        return userRepository.findAll();
    }

    public User getUserById(Long id){
        Optional<User> optionalUser = userRepository.findById(id);
        return optionalUser.orElse(null);
    }

    public User createUser(User user){
        return userRepository.save(user);
    }

    public void deleteUser(Long id){
        userRepository.deleteById(id);
    }

    public User updateUser(User user){
        return userRepository.save(user);
    }


    public Optional<User> findUserByEmail(String email){
        return userRepository.findAll().stream().filter(user -> user.getEmail().equals(email)).findFirst();
    }


}
